[Bug target/58529] GCC -funroll-loops 150% slower with -march=native on x86-64
burnus at gcc dot gnu.org
gcc-bugzilla@gcc.gnu.org
Thu Sep 26 07:36:00 GMT 2013
http://gcc.gnu.org/bugzilla/show_bug.cgi?id=58529
--- Comment #10 from Tobias Burnus <burnus at gcc dot gnu.org> ---
Playing around with --param max-unroll-times= gives:
0 real 0m1.499s user 0m1.497s sys 0m0.000s
1 real 0m1.492s user 0m1.490s sys 0m0.000s
2 real 0m1.138s user 0m1.137s sys 0m0.000s
3 real 0m1.146s user 0m1.144s sys 0m0.000s
4 real 0m0.932s user 0m0.930s sys 0m0.001s
5 real 0m0.955s user 0m0.953s sys 0m0.000s
6 real 0m0.934s user 0m0.933s sys 0m0.000s
7 real 0m0.934s user 0m0.932s sys 0m0.001s
8 real 0m2.480s user 0m2.477s sys 0m0.000s
9 real 0m2.481s user 0m2.479s sys 0m0.000s
10 real 0m2.482s user 0m2.478s sys 0m0.001s
11 real 0m2.480s user 0m2.477s sys 0m0.000s
12 real 0m2.477s user 0m2.474s sys 0m0.000s
More information about the Gcc-bugs
mailing list